---
comments: true
pdf: false
date: 2025-03-15
authors:
  - stephan
categories:
  - Europa
  - Digitale Souveränität
  - Servervirtualisierung
links:
  - Apache CloudStack: https://cloudstack.apache.org/
  - Hyper-V: https://learn.microsoft.com/de-de/windows-server/virtualization/hyper-v/hyper-v-overview?pivots=windows
  - KVM: https://linux-kvm.org/page/Main_Page
  - Proxmox VE: https://proxmox.com/en/products/proxmox-virtual-environment/overview
  - XCP-NG: https://xcp-ng.org/
  - Xen: https://xenproject.org/
  - Xen Orchestra: https://xen-orchestra.com/#!/xo-home
---
# Digitale Souveränität durch freie Hypervisoren: Unabhängigkeit von proprietären Virtualisierungslösungen

In der heutigen IT-Landschaft ist die Virtualisierung von Servern ein unverzichtbarer Bestandteil moderner Infrastrukturen. Hypervisoren ermöglichen es, mehrere virtuelle Maschinen (VMs) auf einer physischen Hardware auszuführen, wodurch Ressourcen effizienter genutzt und Betriebskosten gesenkt werden können. Ein besonders wichtiger Aspekt dabei ist die **digitale Souveränität** – die Kontrolle über die eigenen IT-Systeme und Daten, ohne von einzelnen Anbietern abhängig zu sein.

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/datacenter.jpg" loading="lazy" />
  <figcaption>Bei der Servervirtualisierung kann man durch den Einsatz von freien Hypervisoren einen Schritt in die digitale Unabhängigkeit erreichen (Foto von <a href="https://unsplash.com/de/@tvick?utm_content=creditCopyText&utm_medium=referral&utm_source=unsplash">Taylor Vick</a> auf <a href="https://unsplash.com/de/fotos/kabelnetz-M5tzZtFCOfs?utm_content=creditCopyText&utm_medium=referral&utm_source=unsplash">Unsplash</a>)</figcaption>
</figure>
      
<!-- more -->

## Herausforderungen durch Lizenzänderungen bei VMware

VMware war lange Zeit ein führender Anbieter im Bereich der Servervirtualisierung. Mit der Übernahme durch Broadcom Ende 2023 änderte sich jedoch nicht nur das Lizenzmodell erheblich. Broadcom hat außerdem Teile von VMware, wie die End-User-Computing-Sparte an KKR, abgestoßen und seinen strategischen Fokus verändert. Die Anzahl der VMware-Produkte wurde drastisch reduziert, und viele Unternehmen sahen sich mit erhöhten Kosten durch neue Abonnementmodelle konfrontiert. Dies verstärkte die Abhängigkeit von VMware und beeinträchtigte die digitale Souveränität vieler Unternehmen. Zudem bestehen Bedenken hinsichtlich der langfristigen Produktstrategie und des Supports unter Broadcom.

## Exkurs: Was sind eigentlich Hypervisoren?

In der Welt der Virtualisierungstechnologie spielen Hypervisoren eine zentrale Rolle, da sie die Grundlage für die Erstellung und Verwaltung virtueller Maschinen (VMs) bilden. Dabei werden Hypervisoren hauptsächlich in zwei Kategorien unterteilt: *Typ-1-* und *Typ-2-Hypervisoren*.

### Typ-1-Hypervisoren (Bare-Metal-Hypervisoren)

*Typ-1-Hypervisoren* laufen direkt auf der Hardware des Host-Systems, ohne dass ein darunterliegendes Betriebssystem erforderlich ist. Sie steuern direkt die Hardware-Ressourcen und verwalten die darauf betriebenen Gastbetriebssysteme. Aufgrund ihrer direkten Interaktion mit der Hardware bieten sie in der Regel eine höhere Leistung und Sicherheit, was sie besonders für den Einsatz in Unternehmensrechenzentren attraktiv macht.

![Typ-1-Hypervisor](/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/typ-1-hypervisor.png)

*Hypervisoren vom Typ 1* können nicht nur Server, sondern auch Desktop-Betriebssysteme virtualisieren. *Virtual Desktop Infrastructure* ist die Grundlage der VDI-Lösung, die den Zugriff auf Windows- oder Linux-Desktop-Umgebungen ermöglicht, die in virtuellen Maschinen auf einem zentralen Server ausgeführt werden. Über einen Verbindungsbroker weist der Hypervisor einen virtuellen Desktop aus einem Pool einem einzelnen Benutzer zu, der über das Netzwerk darauf zugreift und so von jedem Gerät aus arbeiten kann. Mit bspw. *Citrix VDI-Lösungen* können virtuelle Desktops mit vollem Funktionsumfang bereitgestellt werden, die die Funktionalität eines physischen Desktops entweder von einem Server vor Ort oder aus der Cloud bieten.

#### Beispiele für Typ-1-Hypervisoren

* **VMware ESXi**: Ein weit verbreiteter Hypervisor, der in vielen Unternehmensumgebungen eingesetzt wird.
* **Microsoft Hyper-V**: Microsofts Lösung für die Servervirtualisierung, die direkt auf der Hardware läuft.
* **Xen**: Ein Open-Source-Hypervisor, der für seine Flexibilität und Sicherheit bekannt ist.
* **KVM (Kernel-based Virtual Machine)**: Ein in den Linux-Kernel integrierter Hypervisor, der Bare-Metal-Performance bietet.

### Typ-2-Hypervisoren (Hosted-Hypervisoren)

*Typ-2-Hypervisoren* werden auf einem bestehenden Betriebssystem installiert und laufen als Anwendung darauf. Sie nutzen die Ressourcen des Host-Betriebssystems, um virtuelle Maschinen zu erstellen und zu verwalten. Obwohl sie einfacher zu installieren und zu verwenden sind, weisen sie oft eine geringere Performance auf als *Typ-1-Hypervisoren*, da sie eine zusätzliche Softwareschicht zwischen der Hardware und den VMs haben. *Typ-2-Hypervisoren* eignen sich besonders für Testumgebungen, Entwicklungszwecke oder den Einsatz auf Desktop-Computern.

![Typ-2-Hypervisor](/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/typ-2-hypervisor.png)

#### Beispiele für Typ-2-Hypervisoren

* **VMware Workstation**: Ein Hypervisor, der es ermöglicht, mehrere Betriebssysteme gleichzeitig auf einem Desktop-Computer auszuführen.
* **Oracle VirtualBox**: Ein Open-Source-Hypervisor, der für seine Benutzerfreundlichkeit und breite Plattformunterstützung bekannt ist.

Die Wahl zwischen einem *Typ-1-* und einem *Typ-2-Hypervisor* hängt von den spezifischen Anforderungen und der geplanten Einsatzumgebung ab. Für produktive Serverumgebungen, in denen Leistung und Sicherheit entscheidend sind, werden oft *Typ-1-Hypervisoren* bevorzugt. Für Entwicklungs- und Testzwecke oder den Einsatz auf Desktop-Systemen bieten *Typ-2-Hypervisoren* aufgrund ihrer einfachen Handhabung und Flexibilität Vorteile.

### Vorteile von Hypervisoren

*Hypervisoren* bieten eine Reihe von Vorteilen, darunter:

* **Erhöhte Hardware-Effizienz**: Ein Virtualisierungshost bietet einem physischen Computersystem die Möglichkeit, mehrere Gastbetriebssysteme (Gäste) nebeneinander auszuführen. Durch diese höhere Auslastung werden die Möglichkeiten der Hardware erheblich erweitert und die Effizienz der Geräte verbessert.
* **Verbesserte Portabilität**: Durch die Isolierung von VMs von der zugrunde liegenden Host-Hardware machen Hypervisoren sie unabhängig und unsichtbar füreinander. Dies wiederum ermöglicht die Live-Migration virtueller Maschinen, d. h. die Verschiebung oder Migration von VMs zwischen verschiedenen physischen Maschinen und entfernten virtualisierten Servern, ohne dass diese angehalten werden müssen, was Failover und Lastausgleich ermöglicht.
* **Verbesserte Sicherheit**: Virtuelle Maschinen laufen auf demselben Host-Computer, sind aber logisch voneinander isoliert und daher nicht von anderen virtuellen Maschinen abhängig. Abstürze, Angriffe oder Malware auf einer VM haben keine Auswirkungen auf andere. Hypervisoren sind extrem sicher.

## Freie Hypervisoren als Alternative

Um dieser Abhängigkeit zu entgehen und die Kontrolle über die eigene IT-Infrastruktur zurückzugewinnen, setzen viele Unternehmen auf freie Hypervisoren. Diese Open-Source-Lösungen bieten nicht nur Kostenvorteile, sondern auch Flexibilität und Unabhängigkeit.

Im Folgenden werden einige der prominentesten freien Hypervisoren detailliert vorgestellt.

### Kernel-based Virtual Machine (KVM)

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/cockpit_kvm_administration.png" loading="lazy" />
  <figcaption>Die Administration von KVM kann bspw. über Cockpit erfolgen</figcaption>
</figure>

**KVM** ist eine Open-Source-Virtualisierungstechnologie, die direkt in den Linux-Kernel integriert ist. Sie ermöglicht es, Linux als Hypervisor zu nutzen, der mehrere isolierte virtuelle Maschinen (VMs) ausführt. Durch die Integration in den Kernel profitiert KVM von den kontinuierlichen Verbesserungen und Sicherheitsupdates des Linux-Betriebssystems. 

^^Hauptmerkmale von KVM:^^

* **Hohe Leistung**: Durch die Nähe zur Hardware bietet KVM nahezu native Performance für VMs. 
* **Umfangreiche Hardware-Unterstützung**: Dank der breiten Hardware-Kompatibilität von Linux ist KVM mit vielen verschiedenen Plattformen kompatibel, was Unternehmen Flexibilität bei der Hardware-Auswahl ermöglicht. 
* **Sicherheit**: Die regelmäßigen Sicherheitsupdates des Linux-Kernels gewährleisten einen hohen Schutzstandard für virtuelle Umgebungen.

### Xen

Der **Xen-Hypervisor** ist ein Open-Source-Typ-1-Hypervisor, der direkt auf der Hardware läuft und die Ausführung mehrerer Betriebssysteme parallel auf einem einzigen Host ermöglicht. Xen ist bekannt für seine Sicherheit und Flexibilität und wird häufig in Cloud-Umgebungen eingesetzt.

^^Hauptmerkmale von Xen:^^

* **Paravirtualisierung**: Unterstützt sowohl vollständige Virtualisierung als auch Paravirtualisierung, was die Leistung in bestimmten Szenarien verbessern kann.
* **Live-Migration**: Ermöglicht das Verschieben laufender VMs zwischen Hosts ohne Unterbrechung des Dienstes. 
* **Sicherheit**: Durch sein Design bietet Xen eine starke Isolation zwischen VMs, was die Sicherheit erhöht. 

### Proxmox Virtual Environment (VE)

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/proxmox-dashboard.png" loading="lazy" />
  <figcaption>Proxmox VE 8.0 - Cluster-Zusammenfassung</figcaption>
</figure>

**Proxmox VE** ist eine Open-Source-Virtualisierungsplattform, die KVM für die Virtualisierung und LXC für Containerisierung kombiniert. Sie bietet eine webbasierte Verwaltungsoberfläche und richtet sich an Unternehmen, die eine integrierte Lösung für Virtualisierung und Containerisierung suchen.

^^Hauptmerkmale von Proxmox VE:^^

* **Integrierte Lösung**: Kombiniert Virtualisierung und Containerisierung in einer Plattform.
* **Webbasierte Verwaltung**: Bietet eine intuitive GUI für die Verwaltung von VMs und Containern.
* **Cluster-Funktionalität**: Unterstützt das Erstellen von Clustern für Hochverfügbarkeit und einfache Skalierung.

### XCP-ng

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/xcpng-center.png" loading="lazy" />
  <figcaption>Das XCP-ng Center erlaubt die Konfiguration eines Clusters oder einzelner Server unter Windows</figcaption>
</figure>

**XCP-ng** ist eine Open-Source-Virtualisierungsplattform, die auf dem Xen-Hypervisor basiert. Sie zielt darauf ab, eine freie und offene Alternative zu kommerziellen XenServer-Implementierungen zu bieten.

^^Hauptmerkmale von XCP-ng:^^

* **Kostenfrei**: Bietet alle Funktionen ohne Lizenzkosten.
* **Kompatibilität**: Unterstützt eine Vielzahl von Betriebssystemen als Gast-VMs.
* **Community-Unterstützung**: Verfügt über eine aktive Community, die regelmäßige Updates und Support bereitstellt.

#### Xen Orchestra (XO)

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/xo-dashboard.png" loading="lazy" />
  <figcaption>Xen Orchestra (XO) bietet vielfältige Möglichkeiten eine XCP-ng-Infrastruktur zu verwalten und in Dashboards bspw. Betriebsstati einzuholen</figcaption>
</figure>

**Xen Orchestra** (**XO**) ist eine umfassende Lösung zur Visualisierung, Verwaltung, Sicherung und Delegation einer XCP-ng- oder XenServer-Infrastruktur. Es bietet eine webbasierte Benutzeroberfläche, eine Kommandozeilenschnittstelle (CLI) sowie eine REST-API und verfügt über einen [Terraform](https://www.terraform.io/)/[OpenTofu](https://opentofu.org/)-Provider und weitere Konnektoren/Plugins.

#### Xen Orchestra Lite (XO Lite)

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/xolite.png" loading="lazy" />
  <figcaption>XO Lite ermöglicht die Verwaltung einzelner XCP-ng-Hosts</figcaption>
</figure>

**Xen Orchestra Lite** (**XO Lite**) ist eine leichtgewichtige Version von Xen Orchestra, die für die Verwaltung einzelner XCP-ng-Hosts direkt über den Webbrowser entwickelt wurde. Im Gegensatz zur vollständigen Xen Orchestra Appliance erfordert XO Lite keine zusätzliche Installation oder Bereitstellung einer virtuellen Appliance. Es ermöglicht grundlegende Verwaltungsaufgaben direkt auf dem Host.

### Microsoft Hyper-V Server

**Microsoft Hyper-V Server** ist eine kostenlose Version von Microsofts Hyper-V-Hypervisor. Obwohl proprietär, bietet es eine kostenfreie Möglichkeit zur Virtualisierung und ist besonders für Windows-zentrierte Umgebungen geeignet.

^^Hauptmerkmale von Hyper-V Server:^^

* **Windows-Integration**: Nahtlose Integration in Windows-Umgebungen und -Tools.
* **Live-Migration**: Unterstützt das Verschieben laufender VMs zwischen Hosts ohne Ausfallzeiten.
* **Skalierbarkeit**: Geeignet für kleine bis große Unternehmensumgebungen.

### Übersicht der freien Hypervisoren

| **Eigenschaft**                      | **KVM**                               | **Xen**                               | **Proxmox VE**                        | **XCP-ng**                            | **Microsoft Hyper-V Server**                                               |
| ------------------------------------ | ------------------------------------- | ------------------------------------- | ------------------------------------- | ------------------------------------- | -------------------------------------------------------------------------- |
| **Lizenz**                           | GNU GPL                               | GNU GPLv2                             | GNU AGPLv3                            | GNU GPLv2                             | Proprietär (kostenlos)                                                     |
| **Hypervisor-Typ**                              | Typ-1                                 | Typ-1                                 | Typ-1                                 | Typ-1                                 | Typ-1                                                                      |
| **Unterstützte Gastbetriebssysteme** | Linux, Windows, andere                | Linux, Windows, andere                | Linux, Windows, andere                | Linux, Windows, andere                | Windows, Linux                                                             |
| **Management-Oberfläche**            | [Virt-Manager](https://virt-manager.org/), [Cockpit](https://cockpit-project.org/)                 | [OpenXenManager](https://openxenmanager.github.io/)             | [Webbasierte GUI](https://pve.proxmox.com/wiki/Graphical_User_Interface)                       | [XCP-ng Center](https://github.com/xcp-ng/xenadmin), [Xen Orchestra](https://xen-orchestra.com/#!/xo-home) (Web-GUI), [XO Lite](https://vates.tech/xen-orchestra-lite/)               | [Hyper-V Manager](https://learn.microsoft.com/de-de/windows-server/virtualization/hyper-v/manage/remotely-manage-hyper-v-hosts), PowerShell                                                |
| **Live-Migration**                   | Ja                                    | Ja                                    | Ja                                    | Ja                                    | Ja                                                                         |
| **Snapshots**                        | Ja                                    | Ja                                    | Ja                                    | Ja                                    | Ja                                                                         |
| **Cluster-Unterstützung**            | Ja                                    | Ja                                    | Ja                                    | Ja                                    | Ja                                                                         |
| **Hochverfügbarkeit**                | Ja                                    | Ja                                    | Ja                                    | Ja                                    | Ja                                                                         |
| **Unterstützung für Container**      | Ja (mit LXC)                          | Nein                                  | Ja (LXC)                              | Nein                                  | Nein                                                                       |
| **Kommerzielle Unterstützung**       | Durch Drittanbieter                   | Ja                                    | Ja                                    | Ja                                    | Ja                                                                         |
| **Migrationsszenarien von VMware**   | Tools von Drittanbietern erforderlich | Tools von Drittanbietern erforderlich | Tools von Drittanbietern erforderlich | Tools von Drittanbietern erforderlich | Microsoft Virtual Machine Converter, System Center Virtual Machine Manager |

### Migrationsmöglichkeiten von VMware zu freien Hypervisoren

Der Wechsel von VMware zu einem freien Hypervisor erfordert sorgfältige Planung. Es gibt verschiedene Tools und Methoden, die den Migrationsprozess unterstützen:

* **Microsoft Hyper-V Server**: Microsoft bietet mit dem System Center Virtual Machine Manager (SCVMM) ein Tool an, das eine wizard-basierte Migration von VMware zu Hyper-V ermöglicht.
* **Andere Hypervisoren**: Für Hypervisoren wie KVM, Xen, Proxmox VE und XCP-ng stehen Tools von Drittanbietern zur Verfügung, die bei der Migration von VMware-Umgebungen unterstützen können. Ein Beispiel hierfür ist das SMTX Migration Tool, das den Übergang von VMware zu alternativen Hypervisoren erleichtert.

## Meine persönliche Einschätzung

Ich habe mit allen fünf Systemen bereits gearbeitet. Ich halte es für sinnvoll, mit sogenannten Distributionen zu arbeiten (in diesem Fall also XCP-ng oder Proxmox VE). Eine Einbeziehung von Hyper-V unterlssse ich an dieser Stelle, da dieser Hypervisor hier außer Konkurrenz antritt, zwar frei ist, aber proprietäre Closed-Source-Software darstellt.

Ein Vergleich zwischen XCP-ng und Proxmox VE bietet wertvolle Einblicke in die Stärken und Schwächen beider Virtualisierungsplattformen. Basierend auf meiner Erfahrung mit beiden Systemen, ein Vergleich und meine Einschätzung.

### Detaillierter Vergleich zwischen XCP-ng und Proxmox VE

| **Merkmal**                     | **XCP-ng**                                                                                                                                                                                                                         | **Proxmox VE**                                                                                                                                                                                                                         |
|---------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **Hypervisor-Typ**              | Typ-1 (Bare-Metal) Hypervisor basierend auf dem Xen-Hypervisor.                                                                                                                                          | Typ-1 (Bare-Metal) Hypervisor basierend auf KVM; zusätzlich Unterstützung für LXC-Container.                                                                                                                                          |
| **Basis-Betriebssystem**        | CentOS.                                                                                                                                         | Debian GNU/Linux.                                                                                                                                         |
| **Management-Oberfläche**       | Benötigt zusätzliche Tools wie Xen Orchestra für die Verwaltung.                                                                                                                      | Integrierte webbasierte Verwaltungsoberfläche.                                                                                                                       |
| **Unterstützung von Containern**| Keine native Unterstützung; Fokus liegt ausschließlich auf der Virtualisierung.                                                                                              | Unterstützt sowohl die Virtualisierung als auch die Containerisierung über LXC.                                                                                               |
| **Storage-Optionen**            | Unterstützt lokale Speicher, NFS, iSCSI, Fibre Channel und SMB/CIFS.                                                                  | Unterstützt lokale Speicher, NFS, iSCSI, ZFS, Ceph und GlusterFS.                                                                  |
| **High Availability (HA)**      | Ja.                                                                                                                                                   | Ja.                                                                                                                                                  |
| **Live-Migration**              | Unterstützt die Live-Migration von VMs.                                                                                                                                                    | Unterstützt die Live-Migration von VMs.                                                                                                                                                    |
| **Backup- und Wiederherstellung**| Integriert mit Xen Orchestra (snapshot-basiert).                                                                  | Integrierte Lösungen (snapshot-basiert, mit Deduplizierung).                                                                 |
| **Cluster-Fähigkeiten**         | Unterstützt Cluster mit bis zu 64 Knoten.                                                                 | Unterstützt Cluster mit mehreren Knoten; genaue Anzahl variiert je nach Konfiguration.                                                                |
| **Snapshot-Funktionalität**     | Unterstützt geplante und automatische Snapshots.                                                                  | Unterstützt eine unbegrenzte Anzahl von Snapshots für VMs.                                                                 |
| **Netzwerkmanagement**          | Verbessertes Netzwerkmanagement über die GUI; unterstützt VLAN, PVLAN, Open vSwitch und Netzwerk-Bonding.                                                                  | Bietet umfassende Netzwerkmanagement-Funktionen über die integrierte GUI.                                                                 |
| **Nested Virtualization**       | Unterstützt verschachtelte Virtualisierung.                                                                  | Unterstützt verschachtelte Virtualisierung.                                                                  |
| **Kosten (Supportprogramme)**   | Kommerzieller Support verfügbar; genaue Kosten variieren je nach Anbieter und Leistungsumfang.                                                                 | Kommerzieller Support verfügbar; genaue Kosten variieren je nach Anbieter und Leistungsumfang.                                                               |

### Vorteile von XCP-ng

* **Enterprise Virtualization Platform**: XCP-ng ist als Enterprise-Virtualisierungsplattform konzipiert, die für große und komplexe Infrastrukturen geeignet ist.
* **Stabilität und Betriebszeit**: Bietet eine hohe Stabilität und Zuverlässigkeit, was für den unterbrechungsfreien Betrieb von entscheidender Bedeutung ist.
* **Nested Virtualization**: Unterstützt die verschachtelte Virtualisierung, wodurch virtuelle Maschinen innerhalb anderer VMs betrieben werden können.
* **Xen Orchestra**: Mit der Installation von Xen Orchestra erhält man eine leistungsstarke, webbasierte Verwaltungsoberfläche mit erweiterten Funktionen.
* **Erweitertes Netzwerkmanagement**: Bietet ein verbessertes Netzwerkmanagement über die GUI, einschließlich Unterstützung für VLAN, PVLAN und Open vSwitch.
* **Cross-Cluster-Ressourcenmigration**: Mit XCP-ng können virtuelle Maschinen (VMs) zwischen verschiedenen Pools migriert werden, auch bekannt als Cross-Pool-Migration. Diese Funktion ermöglicht es, VMs von einem Cluster oder Pool zu einem anderen zu verschieben, was besonders nützlich ist, wenn Hardware aktualisiert oder Workloads neu verteilt werden.

### Vorteile von Proxmox VE

* **Webbasierte Verwaltungsoberfläche**: Proxmox VE bietet standardmäßig eine benutzerfreundliche webbasierte GUI, die die Verwaltung und Überwachung von VMs und Containern erleichtert. Im Gegensatz dazu erfordert XCP-ng die zusätzliche Installation von Xen Orchestra für eine vergleichbare Benutzererfahrung.
* **Unterstützung für LXC-Container**: Neben der Virtualisierung von VMs unterstützt Proxmox VE auch LXC-Container, was eine effiziente und ressourcenschonende Virtualisierung ermöglicht. XCP-ng konzentriert sich ausschließlich auf die Virtualisierung von VMs.
* **ZFS-Unterstützung**: Proxmox VE bietet native Unterstützung für das ZFS-Dateisystem, das fortschrittliche Funktionen wie Snapshots, Datenintegrität und effiziente Datenkompression bietet. Diese Funktionalität ist in XCP-ng nicht standardmäßig integriert.

### Migration von VMware

Beide Hypervisoren bieten die Migration von VMware an.

XCP-ng nutzt in Verbindung mit Xen Orchestra das V2V-Tool ("VMware to Vates") für die Migration von VMware-VMs zum Vates-Stack. Dieser Prozess beginnt mit dem Export eines initialen Snapshots der VMware-VM, der ohne Unterbrechung des VM-Betriebs durchgeführt wird. Nach Abschluss dieser Replikation wird die VM heruntergefahren, und es werden nur die seit dem Snapshot geänderten Daten übertragen. Anschließend wird die VM auf der XCP-ng-Plattform gestartet, was die Ausfallzeit minimiert. Der gesamte Migrationsprozess ist weitgehend automatisiert und erfordert nur minimale manuelle Eingriffe.[^1]

Proxmox VE bietet sowohl einen automatischen als auch einen manuellen Import von virtuellen Maschinen aus VMware-Lösungen an. Ein Live-Import ist ebenso möglich. Der in Proxmox VE 8 eingeführte Importer, der direkt auf den ESXi-Host zugreift, ermöglicht eine Art "Live-Import". Da die VM-Daten direkt vom laufenden ESXi-Host gelesen werden, ist die Downtime minimal. Die VM wird auf dem ESXi heruntergefahren, sobald der Kopiervorgang beendet ist, und auf Proxmox VE gestartet.[^2]

Aus eigener Erfahrung muss ich sagen, dass unter beiden Systemen eine Migration sauber geplant werden muss. Insbesondere bei älteren virtuellen Maschinen auf VMware-ESXi-basierenden Servern ist der Import hin und wieder etwas schwieriger. Ich eruiere dann gerne, ob ggf. eine Neuinstallation und Migration der Information in der neuen Umgebung sinnvoller ist.

### Kosten und Support

* **XCP-ng**: Die Community-Edition von XCP-ng ist vollständig kostenlos und Open Source. Für Unternehmen bietet Vates kommerziellen Support mit 24/7-Verfügbarkeit an, dessen Kosten je nach Leistungsumfang variieren.[^3]
    * **Xen Orchestra** (**XO**): XO gibt es sowohl in einer kommerziellen[^4], als auch in einer freien Applikations-Variante ([XOA](https://docs.xen-orchestra.com/installation#xoa)). Es kann ebenso [aus den Quellen installiert](https://docs.xen-orchestra.com/installation#from-the-sources) werden. Mit administrativen Kenntnissen ist dies problemlos möglich - ich habe diese Variante mehrere Jahre eingesetzt mit einem Cluster und mehreren Einzelhosts.
* **Proxmox VE**: Proxmox VE kann kostenlos genutzt werden, jedoch bietet das Unternehmen kostenpflichtige Abonnements an, die Zugang zu stabilen Updates und erweitertem Support ermöglichen. Die Preise für diese Abonnements sind gestaffelt und richten sich nach dem gewünschten Support-Level.[^5]

### Das Ende der Windows Terminal Server ...

Die Nutzung von Windows Terminal Servern als Multi-Session-Arbeitsumgebung steht vor bedeutenden Veränderungen. Microsoft hat angekündigt, den Support für Microsoft 365 Apps auf Windows Server 2016 und 2019 im Oktober 2025 sowie auf Windows Server 2022 im Oktober 2026 einzustellen.

Nach diesen Terminen wird der Einsatz von Microsoft 365 Apps auf den genannten Server-Versionen nicht mehr unterstützt, was erhebliche Auswirkungen auf Unternehmen hat, die diese Kombination nutzen.

Häufig wird in diesem Zusammenhang Azure Virtual Desktop (AVD) als primäre Alternative hervorgehoben. AVD ist ein flexibler Cloud-Dienst, der Desktop- und Anwendungsvirtualisierung ermöglicht und von Microsoft intensiv beworben wird. Allerdings gibt es auch andere Lösungen, die in Betracht gezogen werden können.

Eine bemerkenswerte Alternative ist [UDS Enterprise](https://udsenterprise.com/en/) in Kombination mit XCP-ng. UDS Enterprise ist ein plattformübergreifender Connection Broker, der die Bereitstellung und Verwaltung von Windows- und Linux-Desktops sowie Anwendungen ermöglicht. In Verbindung mit XCP-ng, einer Open-Source-Virtualisierungsplattform, entsteht eine vollständig Open-Source-basierte VDI-Lösung. Diese Kombination bietet alle notwendigen Komponenten, um eine Desktop- und Anwendungsvirtualisierungsinfrastruktur einfach, sicher und kosteneffizient aufzubauen, zu verwalten und bereitzustellen.

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/uds-enterprise-connection-broker.png" loading="lazy" />
  <figcaption>Der Zugriff auf UDS Enterprise aus erfolgt bspw. über HTML5. Die Nutzer können wie gewohnt auf ihre virtuellen Windows- und Linux-Desktops und ihre virtuellen Windows-Anwendungen zugreifen.</figcaption>
</figure>

Durch den Einsatz von UDS Enterprise und XCP-ng können Unternehmen ihre Virtualisierungsumgebung unabhängig von proprietären Cloud-Diensten gestalten und dabei von den Vorteilen einer Open-Source-Lösung profitieren. Diese Alternative bietet Flexibilität und Kontrolle, insbesondere für Organisationen, die spezifische Anforderungen haben oder lokale Datenhaltung bevorzugen.

### Mein persönliches Fazit zu beiden Lösungen

Aus meiner persönlichen Erfahrung mit beiden Plattformen habe ich festgestellt, dass sowohl XCP-ng als auch Proxmox VE robuste und leistungsfähige Virtualisierungslösungen darstellen. Proxmox VE überzeugt durch seine benutzerfreundliche, integrierte Verwaltungsoberfläche und die Unterstützung von Containern, was es besonders flexibel für verschiedene Anwendungsfälle macht. Allerdings erfordert die Verwaltung von Windows-VMs in Proxmox VE oft zusätzliche Konfigurationen, insbesondere im Hinblick auf die Integration von VirtIO-Treibern.

XCP-ng hingegen bietet durch die Verwendung des Xen-Hypervisors eine starke Isolation zwischen den VMs, was die Sicherheit erhöht. Die optimierten Windows-Treiber erleichtern die Verwaltung von Windows-VMs erheblich und reduzieren potenzielle Komplikationen. Obwohl XCP-ng keine native Unterstützung für Container bietet, überzeugt es durch seine Stabilität und Leistung im Enterprise-Umfeld.

In Unternehmensumgebungen, in denen Sicherheit, Performance und eine klare Trennung der Virtualisierungsressourcen im Vordergrund stehen, halte ich XCP-ng für die geeignetere Wahl. Die Notwendigkeit externer Management-Tools wie Xen Orchestra kann zwar initialen Mehraufwand bedeuten, bietet jedoch eine modulare und anpassbare Verwaltungsstruktur, die den Anforderungen großer IT-Infrastrukturen gerecht wird.

Ein nicht unerwähnt bleibender Punkt ist, dass für Proxmox VE und XCP-ng [Terraform](https://www.terraform.io/)/[OpenTofu](https://opentofu.org/)-Provider bereitstehen und sich beide somit in bestehende oder zu etablierende Infrastructure-as-Code-Konzepte integrieren lassen. Beide Lösungen haben zudem leistungsfähige APIs (XCP-ng in Verbindung mit Xen Orchestra), welche weitere Integrationsmöglichkeiten zulassen.

Mit XCP-ng erhält man zudem eine Lösung, mit welcher man mithilfe von UDS Enterprise auch eine Virtual-Desktop-Infrastructure (fast) unabhängig von Microsoft aufbauen kann.

Abschließend lässt sich sagen, dass die Wahl zwischen XCP-ng und Proxmox VE stark von den spezifischen Anforderungen und Prioritäten des jeweiligen Unternehmens abhängt. Während Proxmox VE durch seine Flexibilität und Benutzerfreundlichkeit punktet, überzeugt XCP-ng durch seine Sicherheitsarchitektur und optimierte Leistung im Enterprise-Bereich.

## Zusammenfassung

Die Abhängigkeit von proprietären Lösungen wie VMware kann die digitale Souveränität eines Unternehmens beeinträchtigen, insbesondere wenn Lizenzänderungen zu erhöhten Kosten führen. Freie Hypervisoren bieten eine attraktive Alternative, die nicht nur Kosten spart, sondern auch die Kontrolle über die eigene IT-Infrastruktur stärkt. Durch sorgfältige Planung und den Einsatz geeigneter Migrationstools können Unternehmen erfolgreich zu diesen Open-Source-Lösungen wechseln.

Proxmox VE und XCP-ng sind quasi europäische (🇪🇺) Software. Proxmox VE wird von der [Proxmox Server Solutions GmbH](https://proxmox.com/de/ueber-uns/ueber-uns/unternehmen) aus Wien (Österreich, 🇦🇹) bereitgestellt, während XCP-ng (und natürlich Xen Orchestra) von [Vates](https://vates.tech/about/) aus Frankreich (🇫🇷) vorangetrieben wird. Nehmen wir noch UDS Enterprise ([Virtual Cable S.L.U.](https://virtualcable.net/en/), Spanien, 🇪🇦) mit in das Konstrukt auf, so haben wir wirklich gute europäische Alternativen!

Um es noch ein bisschen größer zu Denken: alle vorgestellten Hypervisoren (Hyper-V allerdings lediglich in Version Hyper-V 2012 R2)integrieren sich in [**Apache CloudStack**](https://cloudstack.apache.org/). Apache CloudStack ist eine Open-Source-Softwareplattform, die es ermöglicht, Infrastrukturressourcen wie Rechenleistung, Netzwerk und Speicher in öffentlichen, privaten oder hybriden Cloud-Umgebungen bereitzustellen, zu verwalten und zu orchestrieren.

<figure>
  <img src="/blog/images/250315-digitale-souveraenitaet-durch-freie-hypervisoren/cloudstack-ui.png" loading="lazy" />
  <figcaption>Apache CloudStack Web UI nach Login</figcaption>
</figure>

Ich halte es für erstrebenswert sich mit diesen Technologien auseinanderzusetzen. In meinen Augen müssen wir uns in Europa intensiv mit Basistechnologien auseinandersetzen - um die digitale Abhängigkeit von Big Tech zu reduzieren, damit wir eigene Lösungen auf dieser Basis entwickeln und bereitstellen können. Dazu gehört es auch, sich mit europäischen Lösungen zu identifizieren und sie natürlich einzusetzen.

## Key-Facts

* **Digitale Souveränität**: Freie Hypervisoren ermöglichen Unabhängigkeit von proprietären Anbietern.
* **Kostenersparnis**: Open-Source-Lösungen reduzieren Lizenzkosten.
* **Flexibilität**: Anpassungsfähigkeit an spezifische Anforderungen.
* **Migrationsunterstützung**: Verfügbarkeit von Tools für den Übergang von VMware.
* **Zukunftssicherheit**: Vermeidung von Abhängigkeiten und Kontrolle über die eigene IT.

[^1]: [https://docs.xcp-ng.org/installation/migrate-to-xcp-ng/#-from-vmware](https://docs.xcp-ng.org/installation/migrate-to-xcp-ng/#-from-vmware)

[^2]: [https://pve.proxmox.com/wiki/Migrate_to_Proxmox_VE](https://pve.proxmox.com/wiki/Migrate_to_Proxmox_VE)

[^3]: [https://xcp-ng.com/pricing.html](https://xcp-ng.com/pricing.html)

[^4]: [https://xen-orchestra.com/#!/xo-pricing](https://xen-orchestra.com/#!/xo-pricing)

[^5]: [https://proxmox.com/en/products/proxmox-virtual-environment/pricing](https://proxmox.com/en/products/proxmox-virtual-environment/pricing)