---
comments: true
pdf: false
date: 2025-03-18
authors:
  - stephan
categories:
  - Informationssicherheit
  - Datenschutz
  - KI
---
# Wenn Maschinen träumen und programmieren: Eine kritische Betrachtung von KI-generierten Inhalten

In der heutigen digitalen Ära sind Künstliche Intelligenz (KI) und ihre Anwendungen allgegenwärtig. Ob als Suchmaschine, Übersetzer oder bei der Text- und Bildgenerierung – und zunehmend auch bei der Erstellung von Software-Code – KI-Tools erleichtern unseren Alltag und steigern die Effizienz in vielen Bereichen. Doch trotz ihrer beeindruckenden Fähigkeiten ist es essenziell, stets einen kritischen Blick auf die Ergebnisse von KI-Systemen zu werfen. Ein zentraler Aspekt dabei ist das Phänomen der sogenannten "KI-Halluzinationen". Darüber hinaus birgt insbesondere die Fähigkeit von KI, Code zu generieren, erhebliche Risiken.

<figure>
  <img src="/blog/images/250318-wenn-maschinen-traeumen-und-programmieren/title-image.png" loading="lazy" />
  <figcaption>Wenn Maschinen träumen und programmieren: Die Grenzen zwischen menschlicher und künstlicher Intelligenz verschwimmen, und es entstehen neue Risiken (Image created by AI)</figcaption>
</figure>

<!-- more -->

## Was sind KI-Halluzinationen?

KI-Halluzinationen beziehen sich auf Situationen, in denen ein KI-System falsche oder vollständig erfundene Inhalte generiert. Dieses Verhalten hängt unmittelbar mit der Funktionsweise solcher Systeme zusammen.

Grundlage eines KI-Systems sind seine Trainingsdaten, die aus einer Vielzahl von Quellen stammen, darunter Webseiten aller Art, Social-Media-Plattformen, Diskussionsforen, Bücher und wissenschaftliche Artikel. Die Qualität und Zuverlässigkeit dieser Quellen variiert stark, und nicht alle Daten werden vor dem Training auf ihre Richtigkeit überprüft oder kuratiert. Das bedeutet, dass eine KI sich grundsätzlich unkorrekte Informationen aneignen und diese auch wiedergeben kann.

Hinzu kommt, dass große Sprachmodelle wie ChatGPT probabilistisch arbeiten. Das heißt, sie generieren Antworten, indem sie die wahrscheinlichste Abfolge von Wörtern basierend auf ihren Trainingsdaten vorhersagen. Stellen Sie sich vor, die KI hat gelernt, dass auf den Satzanfang 'Die Hauptstadt von Frankreich ist...' häufig das Wort 'Paris' folgt. Sie wird 'Paris' vorhersagen, auch wenn die Frage eigentlich nach der Hauptstadt von Deutschland verlangt. Die KI versteht den Inhalt nicht wirklich, sondern nutzt statistische Wahrscheinlichkeiten. Dies kann letztlich zu falschen oder vollständig erfundenen Inhalten führen – den sogenannten KI-Halluzinationen.

## Gezielte Manipulation von KI-Modellen

Neben unbeabsichtigten Halluzinationen gibt es auch gezielte Manipulationen von KI-Modellen, die bewusst darauf trainiert werden, bestimmte Informationen zu verzerren oder zu verschweigen.

Während KI-Modelle in offenen Gesellschaften oft darauf ausgelegt sind, möglichst viele Informationen bereitzustellen (auch wenn sie nicht immer korrekt sind), gibt es auch gezielte politische Eingriffe in das Training und die Filterung der Antworten. Einige Beispiele:

- **China:** Dort entwickelte KI-Systeme wie Ernie Bot (von Baidu) sind so programmiert, dass sie kritische politische Themen vermeiden oder nur die offizielle Regierungsmeinung wiedergeben. Fragen zu Themen wie Hongkong, Tibet oder der Kommunistischen Partei werden entweder umgangen oder systemtreu beantwortet.
- **Russland:** Ähnlich werden in Russland entwickelte KI-Systeme so trainiert, dass sie staatlich kontrollierte Narrative unterstützen und kritische Stimmen unterdrücken.
- **Westliche Modelle mit ethischen Einschränkungen:** Auch westliche KI-Modelle wie ChatGPT oder Google Gemini haben Einschränkungen, um beispielsweise Hassrede zu vermeiden. Diese Filter können jedoch auch zu Kritik führen, wenn sie als zu einseitig oder ideologisch wahrgenommen werden.

### Der Einfluss von Desinformationskampagnen

Aktuelle Untersuchungen zeigen, dass westliche KI-Modelle nicht nur durch interne Filter beeinflusst werden, sondern auch durch externe Desinformationskampagnen.

Ein prominentes Beispiel ist das sogenannte "Pravda"-Netzwerk, ein russisches Desinformationsnetzwerk, das gezielt darauf abzielt, westliche KI-Systeme mit falschen Informationen zu infiltrieren. Dies geschieht beispielsweise durch das Erstellen gefälschter Nachrichtenwebseiten, das massenhafte Posten von Kommentaren in Foren und sozialen Medien sowie durch die Manipulation von Online-Enzyklopädien.

Durch die massenhafte Verbreitung von Fake News versuchen solche Netzwerke, die Trainingsdaten von KI-Modellen zu beeinflussen, ein Vorgehen, das als *LLM-Grooming* (Large Language Model Grooming) bezeichnet wird. *LLM-Grooming bezeichnet die gezielte Beeinflussung der Trainingsdaten großer Sprachmodelle durch die Verbreitung falscher oder irreführender Informationen.* Eine Studie von NewsGuard ergab, dass die zehn führenden KI-Systeme in 33,5 Prozent der Fälle Falschmeldungen dieses Netzwerks übernommen haben.

Auch außerhalb staatlicher Einflussnahme gibt es Versuche, KI-Modelle zu manipulieren. So könnten Unternehmen versuchen, die Darstellung ihrer Produkte in KI-generierten Texten zu verbessern, oder Interessengruppen könnten versuchen, bestimmte Narrative zu verbreiten.

### Warum ist das relevant?

Die gezielte Manipulation von KI-Systemen durch Desinformationskampagnen hat weitreichende Konsequenzen:

- **Verlust des Vertrauens:** Wenn Nutzer feststellen, dass KI-Systeme falsche oder manipulierte Informationen liefern, kann dies zu einem generellen Vertrauensverlust in technologische Anwendungen führen.
- **Verbreitung von Propaganda:** Durch die Integration von Desinformationen in KI-Antworten können propagandistische Inhalte unbemerkt und massenhaft verbreitet werden.
- **Beeinflussung der öffentlichen Meinung:** Manipulierte KI-Systeme können dazu beitragen, die öffentliche Meinung in eine bestimmte Richtung zu lenken, indem sie gezielt falsche Informationen verbreiten.
- **Verstärkung bestehender Ungleichheiten:** Wenn die Trainingsdaten, die einer KI zugrunde liegen, bereits Verzerrungen (Bias) enthalten, kann die KI diese Verzerrungen verstärken und in ihren Ergebnissen reproduzieren. Dies kann zu Diskriminierung in verschiedenen Bereichen führen.
- **"Black Box"-Problem:** Viele KI-Modelle, insbesondere im Bereich des Deep Learning, sind so komplex, dass ihre Entscheidungsfindung selbst für Experten nicht mehr nachvollziehbar ist. Dieses "Black Box"-Problem erschwert die Fehlerbehebung, die Überprüfung auf Fairness und untergräbt das Vertrauen in die Technologie.
- **Missbrauch für schädliche Zwecke:** KI-Technologien können für eine Vielzahl schädlicher Zwecke missbraucht werden, von der Erstellung überzeugender Deepfakes bis hin zur Entwicklung autonomer Waffensysteme.

## KI als Programmierer: Risiken bei der automatisierten Code-Erstellung

Neben der Generierung von Texten und Bildern werden KI-Modelle zunehmend auch zur Erstellung von Software-Code eingesetzt. Ähnlich wie bei Texten basiert dies auf dem Training mit riesigen Mengen an vorhandenem Code, beispielsweise aus öffentlichen Code-Repositories wie GitHub, aus Code-Dokumentationen und anderen Quellen. Auch hier gibt es erhebliche Risiken:

- **Fehlerhafter Code:** KI kann Code mit logischen Fehlern, Syntaxfehlern oder ineffizienten Algorithmen produzieren.
- **Sicherheitslücken:** KI kann Code generieren, der bekannte oder unbekannte Sicherheitslücken enthält (z.B. SQL-Injections, Cross-Site-Scripting, Buffer Overflows).
- **Verborgene Abhängigkeiten:** KI kann Code generieren, der von externen Bibliotheken oder Modulen abhängt, die möglicherweise selbst fehlerhaft oder kompromittiert sind.
- **Urheberrechtsverletzungen:** KI kann Code generieren, der urheberrechtlich geschütztes Material enthält, ohne dies kenntlich zu machen.
- **Mangelnde Erklärbarkeit:** Ähnlich wie bei Texten ist oft nicht nachvollziehbar, *warum* die KI einen bestimmten Code generiert hat. Das erschwert die Fehlersuche und das Vertrauen in den Code.
- **"Overreliance" (Übermäßiges Vertrauen):** Entwickler verlassen sich möglicherweise zu sehr auf die KI und überprüfen den generierten Code nicht sorgfältig genug.
- **"Prompt Injection"-Angriffe:** Durch spezielle Eingabeaufforderungen (Prompts) kann versucht werden, ein KI-Modell zur Generierung von schädlichem Code zu verleiten oder vertrauliche Informationen preiszugeben. Dies stellt eine ernstzunehmende Bedrohung dar.

Es ist wichtig zu beachten, dass diese Risiken nicht bedeuten, dass KI-gestützte Code-Generierung grundsätzlich schlecht ist. Sie kann die Produktivität von Entwicklern erheblich steigern. Entscheidend ist jedoch ein bewusster und verantwortungsvoller Umgang.

## Best Practices für den verantwortungsvollen Einsatz von KI

Um den Herausforderungen und ethischen Fragen im Umgang mit KI zu begegnen, sollten folgende Best Practices berücksichtigt werden.

### Für Text- und Bildgenerierung

- **Datenminimierung:** Erfassen Sie nur die Daten, die *unbedingt* für die Funktion der KI-Anwendung erforderlich sind. Vermeiden Sie *das Sammeln sensibler Daten, die nicht direkt zum Anwendungszweck beitragen.*
- **Transparenz und Erklärbarkeit:** Stellen Sie sicher, dass die Entscheidungsprozesse der KI nachvollziehbar sind. *Setzen Sie auf Techniken wie 'Explainable AI' (XAI), um die Entscheidungsfindung der KI nachvollziehbar zu machen. Dokumentieren Sie die Trainingsdaten und Algorithmen, um eine spätere Überprüfung zu ermöglichen.* Dies fördert das Vertrauen der Nutzer und ermöglicht es, potenzielle Fehlerquellen zu identifizieren.
- **Fairness und Inklusion:** Achten Sie darauf, dass die KI-Systeme keine diskriminierenden Entscheidungen treffen und alle Nutzergruppen gleichermaßen berücksichtigen. *Überprüfen Sie die Trainingsdaten auf mögliche Verzerrungen (Bias), die zu diskriminierenden Ergebnissen führen könnten. Setzen Sie Algorithmen ein, die Fairness-Metriken berücksichtigen und benachteiligte Gruppen nicht systematisch schlechter stellen. Führen Sie regelmäßige Audits durch, um die Fairness der KI-Anwendung zu überprüfen.*
- **Verantwortung und Rechenschaftspflicht:** Definieren Sie klare Verantwortlichkeiten für die Entwicklung, Implementierung und Überwachung von KI-Systemen. *Definieren Sie intern klare Rollen und Verantwortlichkeiten. Wer ist für die Datenqualität zuständig? Wer überwacht die Ergebnisse der KI? Wer ist Ansprechpartner bei Problemen?*
- **Schutz der Privatsphäre:** Implementieren Sie robuste Datenschutzmaßnahmen, um die persönlichen Daten der Nutzer zu schützen.

### Zusätzlich für KI-gestützte Code-Generierung:

- **Sorgfältige Überprüfung:** KI-generierter Code sollte *immer* von erfahrenen Entwicklern überprüft werden. Code-Reviews sind unerlässlich.
- **Statische Code-Analyse:** Tools zur statischen Code-Analyse können helfen, Fehler und Sicherheitslücken im KI-generierten Code automatisch zu erkennen.
- **Dynamische Code-Analyse:** "Fuzzing" und andere dynamische Testmethoden können helfen, Schwachstellen aufzudecken, die bei der statischen Analyse übersehen wurden.
- **Sichere Bibliotheken:** Verwenden Sie nur vertrauenswürdige und regelmäßig aktualisierte Bibliotheken und Frameworks.
- **Sandboxing:** Führen Sie KI-generierten Code in einer isolierten Umgebung (Sandbox) aus, um Schäden am System zu vermeiden.
- **Eingeschränkte Rechte:** Geben Sie KI-generiertem Code nur die minimal erforderlichen Berechtigungen.
- **Dokumentation:** Dokumentieren Sie, welcher Code von der KI generiert wurde und welche Änderungen vorgenommen wurden.
- **Fortbildung:** Entwickler sollten im Umgang mit KI-basierten Code-Generatoren geschult werden und sich der Risiken bewusst sein.
- **Hybrider Ansatz:** Betrachten Sie die KI als Assistenten, nicht als Ersatz für menschliche Entwickler. Der Mensch behält die Kontrolle und trifft die endgültigen Entscheidungen.

## Fazit und Ausblick

Künstliche Intelligenz bietet immense Möglichkeiten und Vorteile. Dennoch ist es von größter Bedeutung, die potenziellen Risiken und Herausforderungen im Umgang mit KI-Systemen zu erkennen. Insbesondere die Gefahr von KI-Halluzinationen, die gezielte Manipulation durch Desinformationskampagnen und die Generierung von fehlerhaftem oder unsicherem Code erfordern einen kritischen und informierten Umgang mit KI-generierten Inhalten. Nutzer sollten stets die Quellen von Informationen überprüfen und Entwickler müssen KI-generierten Code genauso sorgfältig prüfen wie von Menschen geschriebenen Code. Sie müssen sich der Tatsache bewusst sein, dass auch KI-Systeme anfällig für Fehler und Manipulationen sind.

Es ist zu erwarten, dass die Versuche, KI-Systeme zu manipulieren, in Zukunft zunehmen werden. Dies gilt sowohl für die Verbreitung von Desinformation als auch für Angriffe auf KI-Systeme, die Code generieren. Daher ist es wichtig, dass Forschung und Entwicklung sich intensiv mit der Erkennung und Abwehr solcher Angriffe beschäftigen. Auch die Regulierung von KI-Systemen wird eine wichtige Rolle spielen, um Missbrauch zu verhindern und das Vertrauen der Nutzer zu stärken. Jeder Einzelne kann dazu beitragen, indem er KI-generierte Inhalte kritisch hinterfragt und sich nicht blind auf die Aussagen von Maschinen verlässt.

## Keyfacts

- **KI-Halluzinationen sind ein reales Problem:** KI-Systeme erfinden Fakten oder geben falsche Informationen wieder.
- **Manipulation ist vielfältig:** Sowohl Staaten als auch andere Akteure versuchen, KI-Systeme zu ihren Gunsten zu beeinflussen.
- **Desinformation verbreitet sich über KI:** Gefälschte Nachrichten und Propaganda werden von KI-Systemen übernommen und weiterverbreitet.
- **LLM-Grooming ist eine gezielte Methode:** Die Trainingsdaten von KI werden manipuliert, um die Ergebnisse zu verzerren.
- **KI-generierter Code birgt Risiken:** Fehler, Sicherheitslücken und Urheberrechtsverletzungen sind möglich.
- **Kritisches Denken ist unerlässlich:** Hinterfragen Sie KI-generierte Inhalte *aller Art* und überprüfen Sie die Quellen.
- **Verantwortungsvoller Umgang ist gefragt:** Entwickler, Nutzer und Regulierungsbehörden müssen zusammenarbeiten, um die Risiken von KI zu minimieren.
